@@ -23,8 +23,11 @@ LIB64 = os.path.join(os.path.dirname(__file__), "intercept", "lib64")
 
 
 class Debugger(Intercept):
-    def __init__(self, command, cwd=os.getcwd(), output="cmds.txt", append=False, conf=None):
-        super().__init__(command, cwd, output, append, conf)
+    def __init__(self, command, cwd=os.getcwd(), output="cmds.txt", append=False, intercept_open=False, conf=None):
+        if intercept_open:
+            raise RuntimeError("debugger can't be used to intercept open()")
+
+        super().__init__(command, cwd=cwd, output=output, append=append, intercept_open=intercept_open, conf=conf)
 
         # self.conf["Intercept.preprocess"] = self.conf.get("Intercept.preprocess", True)
         self.debugger = self.__find_debugger()
